#!/usr/bin/env python3

'''
Generates an endless amount of combining characters
'''

import random
import string

combs = list("\u0300\u0301\u0302\u0303\u0304\u0305\u0306\u0307\u0308\u0309\u030A\u030B\u030C\u030D\u030E\u030F")

while True:
    random.shuffle(combs)
    print(random.choice(string.ascii_letters)+"".join(combs), end="", flush=True)




#!/usr/bin/python

# A list of some trouble-some chars

# Some taken from https://bugs.kde.org/show_bug.cgi?id=210329
print(u'\u0307')
print(u'\u2500')
print(u'\u2501')
print(u'\u2502')
print(u'\u2503')
print(u'\u2504')
print(u'\u2505')
print(u'\u2506')
print(u'\u2507')
print(u'\u2508')
print(u'\u2509')
print(u'\u250A')
print(u'\u250B')
print(u'\u250C')
print(u'\u250D')
print(u'\u250E')
print(u'\u250F')

print(u'\u254C')
print(u'\u254D')
print(u'\u254E')
print(u'\u254F')

print(u'\u256D')
print(u'\u256E')
print(u'\u256F')

print(u'\u2570')
print(u'\u2571')
print(u'\u2572')
print(u'\u2573')

